{% if code == "HIGH" %}<i class="fa-solid fa-angles-up"></i>
{% elif code == "MED" %}<i class="fa-solid fa-grip-lines"></i>
{% elif code == "LOW" %}<i class="fa-solid fa-angles-down"></i>
{% elif code == "RIG" %}<i class="fa-solid fa-wrench"></i>
{% elif code == "SUBSYS" %}<i class="fa-solid fa-cubes"></i>
{% elif code == "DRONE" %}<i class="fa-solid fa-robot"></i>
{% elif code == "FIGHTER" %}<i class="fa-solid fa-jet-fighter"></i>
{% elif code == "CARGO" %}<i class="fa-solid fa-box-open"></i>
{% elif code == "FUEL" %}<i class="fa-solid fa-gas-pump"></i>
{% elif code == "FEB" %}<i class="fa-solid fa-life-ring"></i>
{% elif code == "IMPLANT" %}<i class="fa-solid fa-brain"></i>
{% elif code == "BOOSTER" %}<i class="fa-solid fa-flask"></i>
{% else %}<i class="fa-solid fa-circle"></i>{% endif %}
