# Generated by Django 5.2.15 on 2026-06-16 21:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0020_enforcementsettings'),
    ]

    operations = [
        migrations.AddField(
            model_name='doctrinefit',
            name='feb_frigate_type_id',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='assignmentitempolicy',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('FEB', 'Frigate Escape Bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='compliancefinding',
            name='section',
            field=models.CharField(blank=True, choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('FEB', 'Frigate Escape Bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], default='', max_length=8),
        ),
        migrations.AlterField(
            model_name='doctrinefititem',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('FEB', 'Frigate Escape Bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='policyslotrule',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('FEB', 'Frigate Escape Bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='submissionitem',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('FEB', 'Frigate Escape Bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
    ]
