# Generated by Django 5.2.15 on 2026-07-03 21:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0030_compliancesnapshot_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='doctrinefit',
            name='source_policy_bumped_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='doctrinefit',
            name='source_policy_version',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='doctrinefit',
            name='version_bumped_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='enforcementsettings',
            name='stale_grace_days',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='fitassignment',
            name='version',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='fitassignment',
            name='version_bumped_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='fitsubmission',
            name='policy_version',
            field=models.PositiveIntegerField(default=0),
        ),
    ]
