# Generated by Django 5.2.15 on 2026-06-28 01:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0027_doctrinecategory_source_plugin_pk'),
    ]

    operations = [
        migrations.CreateModel(
            name='StructureNameCache',
            fields=[
                ('structure_id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
                ('solar_system_id', models.PositiveIntegerField(blank=True, db_index=True, null=True)),
                ('resolved_at', models.DateTimeField(blank=True, null=True)),
                ('last_attempt_at', models.DateTimeField(blank=True, null=True)),
                ('fail_count', models.PositiveIntegerField(default=0)),
                ('accessible', models.BooleanField(default=True)),
            ],
            options={
                'verbose_name': 'structure name cache entry',
                'verbose_name_plural': 'structure name cache entries',
                'indexes': [models.Index(fields=['resolved_at'], name='fitcheck_st_resolve_a7bf7c_idx'), models.Index(fields=['accessible', 'last_attempt_at'], name='fitcheck_st_accessi_9ebd03_idx')],
            },
        ),
    ]
