# Generated by Django 5.2.15 on 2026-07-07 15:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0033_quantity_zero_and_charge_rule'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='doctrinefit',
            name='default_policy',
        ),
    ]
