# Generated by Django 5.2.15 on 2026-06-12 18:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0003_alter_compliancefinding_code'),
    ]

    operations = [
        migrations.AlterField(
            model_name='compliancefinding',
            name='code',
            field=models.CharField(choices=[('OK', 'Exact match'), ('SUB', 'Allowed substitute'), ('REF', 'Carried in cargo as refit'), ('ANY', 'No enforcement'), ('BAD', 'Not an allowed substitute'), ('MIS', 'Missing'), ('EXT', 'Not part of the fit'), ('QTY', 'Quantity short'), ('HUL', 'Wrong hull'), ('UNR', 'Unrecognized item'), ('IMP', 'Required implant missing'), ('UNV', 'Listed but not verifiable')], max_length=3),
        ),
    ]
