# Generated by Django 5.2.15 on 2026-07-07 15:42

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0035_standard_preset_cargo_25'),
    ]

    operations = [
        migrations.AddField(
            model_name='doctrine',
            name='compliance_policy',
            field=models.ForeignKey(blank=True, help_text="Standing policy preset for this doctrine. Applied to every fitting assignment's policy snapshot on demand, and automatically when a fitting is attached or re-synced.", null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='doctrines', to='fitcheck.compliancepolicy'),
        ),
    ]
