# Generated by Django 5.2.15 on 2026-06-12 20:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0006_alter_compliancefinding_code'),
    ]

    operations = [
        migrations.AddField(
            model_name='fitsubmission',
            name='frigate_escape_bay_type_id',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
