# Generated by Django 5.2.15 on 2026-06-14 19:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0008_add_member_inventory_perms'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_access', 'Can access Fit Check'), ('manage_doctrines', 'Can manage doctrines and fitting standards'), ('review_submissions', 'Can review fit submissions'), ('secure_group_management', 'Secure Group Doctrine Management - can view and decide on submitted ships but cannot create doctrines or change fitting standards'), ('manage_policies', 'Plugin admin - can manage compliance policies'), ('view_compliance_reports', 'Can view org-wide compliance reports'), ('view_member_inventory', "Can browse alliance members' ships and run proactive fit checks"), ('view_own_corp_inventory', "Can browse own-corporation members' ships and run proactive fit checks (scoped to the user's main character's corporation)"))},
        ),
        migrations.AddField(
            model_name='doctrine',
            name='source_plugin_pk',
            field=models.PositiveIntegerField(blank=True, db_index=True, help_text='Primary key of the source row in the `fittings` plugin, if imported.', null=True),
        ),
        migrations.AddField(
            model_name='doctrinefit',
            name='source_plugin_pk',
            field=models.PositiveIntegerField(blank=True, db_index=True, help_text='Primary key of the source row in the `fittings` plugin, if imported.', null=True),
        ),
    ]
