# Generated by Django 5.2.15 on 2026-07-07 14:46

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0032_scanparameters'),
    ]

    operations = [
        migrations.AddField(
            model_name='doctrinefit',
            name='charge_min_quantity_pct',
            field=models.PositiveSmallIntegerField(default=100, help_text='Leeway for synthesized loaded-charge demands (see charge_policy).', validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)]),
        ),
        migrations.AddField(
            model_name='doctrinefit',
            name='charge_policy',
            field=models.CharField(choices=[('EX', 'Strict (exact type only)'), ('VA', 'Standard (variant family)'), ('MB', 'Flexible (meets or beats attributes)'), ('AN', 'No enforcement (anything accepted)')], default='EX', max_length=2),
        ),
        migrations.AddField(
            model_name='fitassignment',
            name='charge_min_quantity_pct',
            field=models.PositiveSmallIntegerField(default=100, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)]),
        ),
        migrations.AddField(
            model_name='fitassignment',
            name='charge_policy',
            field=models.CharField(choices=[('EX', 'Strict (exact type only)'), ('VA', 'Standard (variant family)'), ('MB', 'Flexible (meets or beats attributes)'), ('AN', 'No enforcement (anything accepted)')], default='EX', max_length=2),
        ),
        migrations.AlterField(
            model_name='assignmentitempolicy',
            name='min_quantity_pct',
            field=models.PositiveSmallIntegerField(default=100, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)]),
        ),
        migrations.AlterField(
            model_name='doctrinefititem',
            name='min_quantity_pct',
            field=models.PositiveSmallIntegerField(default=100, help_text='Consumable leeway for bay/cargo items: pass at this percent of the listed quantity. 0 = listed but optional (a pilot carrying none still passes).', validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)]),
        ),
        migrations.AlterField(
            model_name='policyslotrule',
            name='min_quantity_pct',
            field=models.PositiveSmallIntegerField(default=100, help_text='Consumable sections: pass at this percent of the listed quantity. 0 = listed but optional (a pilot carrying none still passes).', validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)]),
        ),
    ]
